@@ -17,8 +17,8 @@ use warnings;
 
 use base qw( Exporter );
 
-our @EXPORT = qw( create_io_object );
-our $VERSIN = '0.01';
+our @EXPORT  = qw( create_io_object );
+our $VERSION = '0.10';
 
 use IO::File;
 use IO::String;
@@ -72,11 +72,11 @@ sub create_io_object {
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2005 by Brian Cassidy
+Copyright 2004-2009 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
 
 =cut
 
-1;
\ No newline at end of file
+1;
